import monetdbe
import os 

path = os.path.dirname(os.path.realpath(__file__))

def read_file(full_path):
    with open(full_path, 'r') as f:
        return f.readlines()

def main():
    conn = monetdbe.connect(autocommit=True)
    if not conn:
        raise RuntimeError(f'Could not establish a connection')

    cursor = conn.cursor()  
    cursor.execute(
        """
            CREATE TABLE LINEITEM (L_ORDERKEY BIGINT NOT NULL, L_PARTKEY INTEGER NOT NULL, L_SUPPKEY     INTEGER NOT NULL, L_LINENUMBER  INTEGER NOT NULL, L_QUANTITY    DECIMAL(15,2) NOT NULL, L_EXTENDEDPRICE  DECIMAL(15,2) NOT NULL, L_DISCOUNT    DECIMAL(15,2) NOT NULL, L_TAX         DECIMAL(15,2) NOT NULL, L_RETURNFLAG  CHAR(1) NOT NULL, L_LINESTATUS  CHAR(1) NOT NULL, L_SHIPDATE    DATE NOT NULL, L_COMMITDATE  DATE NOT NULL, L_RECEIPTDATE DATE NOT NULL, L_SHIPINSTRUCT CHAR(25) NOT NULL, L_SHIPMODE     CHAR(10) NOT NULL, L_COMMENT      VARCHAR(44) NOT NULL);
        """
    )
    cursor.execute(
        f"COPY INTO LINEITEM FROM '{path}/lineitem.tbl' USING DELIMITERS '|',E'|\\n' NULL as '';"
    )
    count = cursor.execute(f"SELECT COUNT(*) FROM LINEITEM")
    print(count.fetchall())
    print(f'Data loaded')

    results = cursor.execute(
        """
        select
            l_returnflag,
            l_linestatus,
            sum(l_quantity) as sum_qty,
            sum(l_extendedprice) as sum_base_price,
            sum(l_extendedprice * (1 - l_discount)) as sum_disc_price,
            sum(l_extendedprice * (1 - l_discount) * (1 + l_tax)) as sum_charge,
            avg(l_quantity) as avg_qty,
            avg(l_extendedprice) as avg_price,
            avg(l_discount) as avg_disc,
            count(*) as count_order
        from
            lineitem
        where
            l_shipdate <= date '1998-12-01' - interval '90' day (3)
        group by
            l_returnflag,
            l_linestatus
        order by
            l_returnflag,
            l_linestatus;
        """
    )

    print(results.fetchall())

if __name__ == "__main__":
    main()